@@ -10,8 +10,8 @@ int Hosts_Init(ConfigFileInfo *ConfigInfo);
 
 BOOL Hosts_TypeExisting(const char *Domain, HostsRecordType Type);
 
-HostsUtilsTryResult Hosts_Try(IHeader *Header, int BufferLength);
+HostsUtilsTryResult Hosts_Try(MsgContext *MsgCtx, int BufferLength);
 
-int Hosts_Get(IHeader *Header, int BufferLength);
+int Hosts_Get(MsgContext *MsgCtx, int BufferLength);
 
 #endif // HOSTS_H_INCLUDED
