@@ -7,6 +7,8 @@
 
 int MMgr_Init(ConfigFileInfo *ConfigInfo);
 
-int MMgr_Send(IHeader *h, int BufferLength);
+int Modules_Update(void);
+
+int MMgr_Send(const char *Buffer, int BufferLength);
 
 #endif // MMGR_H_INCLUDED
