@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <time.h>
 #include "../../stringlist.h"
 #include "../testutils.h"
 #include "../../stringchunk.h"
@@ -8,12 +9,10 @@ int main(void)
 {
     StringChunk c;
 
-    StringList l;
-
     char str[128];
     char Data[64];
 
-    char *si;
+    const char *si;
     char *di;
 
     int n;
@@ -22,9 +21,7 @@ int main(void)
 
     srand(time(NULL));
 
-    StringList_Init(&l, NULL, NULL);
-
-    StringChunk_Init(&c, &l);
+    StringChunk_Init(&c, NULL);
 
     for( n = 70; n < sizeof(str); ++n )
     {
@@ -33,10 +30,10 @@ int main(void)
 
     StringChunk_Add(&c, "a??.exe", "12345", 6);
 
-    si = StringChunk_Enum_NoWildCard(&c, &Start, &di);
+    si = StringChunk_Enum_NoWildCard(&c, &Start, (void **)&di);
     while( si != NULL )
     {
-        int h = StringChunk_Match(&c, si, NULL, &di);
+        int h = StringChunk_Match(&c, si, NULL, (void **)&di);
 
         if( h )
         {
@@ -45,10 +42,10 @@ int main(void)
             printf("STRING : %s\nNOT MATCHED\n\n", si);
         }
 
-        si = StringChunk_Enum_NoWildCard(&c, &Start, &di);
+        si = StringChunk_Enum_NoWildCard(&c, &Start, (void **)&di);
     }
 
-    int h = StringChunk_Match(&c, "asd1.exe", NULL, &di);
+    int h = StringChunk_Match(&c, "asd1.exe", NULL, (void **)&di);
     if( h )
     {
         printf("STRING : %s\nDATA: %s\n\n", "asd1.exe", di);
@@ -56,7 +53,7 @@ int main(void)
         printf("STRING : %s\nNOT MATCHED\n\n", "asd1.exe");
     }
 
-    StringChunk_Free(&c, FALSE);
+    StringChunk_Free(&c, TRUE);
 
     return 0;
 }
